<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
<html>
    <head>
        <title><!-- TMPL_VAR message --></title>
    </head>
    <body>
        <h1><!-- TMPL_VAR message --></h1>
    </body>
</html>
